def get_free_username(original, is_free, limit):
    if is_free(original):
        return original

    for num in range(2, limit):
        username = "{}_{}".format(original, num)
        if is_free(username):
            return username

    raise Exception("Usernames {} and {}_{}-{} are taken".format(
        original, original, 2, limit - 1))



from django.db import models
from django.conf import settings


class CASUser(models.Model):
    user = models.OneToOneField(
        settings.AUTH_USER_MODEL,
        on_delete=models.CASCADE,
        primary_key=True,
    )
    universal_id = models.CharField(max_length=100)



#!/usr/bin/env python
from distutils.core import setup


setup(
    name='django_cas_binder',
    version='1.4',
    description=(
        'A thin wrapper around django-cas-ng that allows to use identifier '
        'other than username.'
    ),
    author='',
    author_email='',
    url='',
    packages=['django_cas_binder', 'django_cas_binder.migrations'],
)
